from django.apps import AppConfig


class CorgyCommonConfig(AppConfig):
    name = 'corgy_common'
    icon = '<i class="material-icons">settings_applications</i>'
